# Changelog

## 0.1.0-alpha.1 (2025-01-21)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/hyperspell/python-sdk/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** api update ([#12](https://github.com/hyperspell/python-sdk/issues/12)) ([14c9569](https://github.com/hyperspell/python-sdk/commit/14c95692111450a03e18b65b9fe84b76b1439741))
* **api:** api update ([#16](https://github.com/hyperspell/python-sdk/issues/16)) ([90ab745](https://github.com/hyperspell/python-sdk/commit/90ab745ece042d2a54a55fec5167db3bfa007618))
* **api:** api update ([#21](https://github.com/hyperspell/python-sdk/issues/21)) ([1b33d5e](https://github.com/hyperspell/python-sdk/commit/1b33d5e6cad083d1f6bfea037ddf79aeb558875b))
* **api:** api update ([#4](https://github.com/hyperspell/python-sdk/issues/4)) ([b44636b](https://github.com/hyperspell/python-sdk/commit/b44636b513256d732590494a99dc0eb1b688df13))
* **api:** api update ([#5](https://github.com/hyperspell/python-sdk/issues/5)) ([3fc9775](https://github.com/hyperspell/python-sdk/commit/3fc97752048e4259b2f0a71358231315fb11cf23))
* **api:** api update ([#7](https://github.com/hyperspell/python-sdk/issues/7)) ([4c43cb7](https://github.com/hyperspell/python-sdk/commit/4c43cb7d7dc11fbe157b9ebb513d753b7210eef4))
* **api:** api update ([#8](https://github.com/hyperspell/python-sdk/issues/8)) ([bbe535f](https://github.com/hyperspell/python-sdk/commit/bbe535f81cefa788f07e6298345bbc1b18b07684))


### Bug Fixes

* **client:** only call .close() when needed ([#11](https://github.com/hyperspell/python-sdk/issues/11)) ([23d4683](https://github.com/hyperspell/python-sdk/commit/23d468363e7b6aa433165ca42491a0351aad4274))
* correctly handle deserialising `cls` fields ([#15](https://github.com/hyperspell/python-sdk/issues/15)) ([dff71c6](https://github.com/hyperspell/python-sdk/commit/dff71c6d918c24b7dcfa0bea38ac7bbdb510b1af))
* **tests:** make test_get_platform less flaky ([#19](https://github.com/hyperspell/python-sdk/issues/19)) ([4886fcf](https://github.com/hyperspell/python-sdk/commit/4886fcf1b23834c6b009c888d68ce8a6b292a79e))


### Chores

* add missing isclass check ([#9](https://github.com/hyperspell/python-sdk/issues/9)) ([12f5ed5](https://github.com/hyperspell/python-sdk/commit/12f5ed56926e50d94b2462636ff8302c29fbf296))
* go live ([#1](https://github.com/hyperspell/python-sdk/issues/1)) ([84713c4](https://github.com/hyperspell/python-sdk/commit/84713c43b10cce946f27e116b7a621c3348a83be))
* **internal:** avoid pytest-asyncio deprecation warning ([#20](https://github.com/hyperspell/python-sdk/issues/20)) ([65f793b](https://github.com/hyperspell/python-sdk/commit/65f793b8d9da0222494949ea590e59123825d57e))
* **internal:** bump httpx dependency ([#10](https://github.com/hyperspell/python-sdk/issues/10)) ([988e555](https://github.com/hyperspell/python-sdk/commit/988e555345b3b193784e7b156d73d3d77eb7d715))
* **internal:** codegen related update ([#14](https://github.com/hyperspell/python-sdk/issues/14)) ([c7e587f](https://github.com/hyperspell/python-sdk/commit/c7e587fc23d72325d491a816a68a55e01d98735b))
* **internal:** codegen related update ([#17](https://github.com/hyperspell/python-sdk/issues/17)) ([9f186e4](https://github.com/hyperspell/python-sdk/commit/9f186e44b8f1c40853cc6f932995379bf187d2a9))
* **internal:** codegen related update ([#6](https://github.com/hyperspell/python-sdk/issues/6)) ([fa47f9e](https://github.com/hyperspell/python-sdk/commit/fa47f9eb5a5677f1a88d5b3034ec900a382f3e45))
* update SDK settings ([#3](https://github.com/hyperspell/python-sdk/issues/3)) ([7d1e0bb](https://github.com/hyperspell/python-sdk/commit/7d1e0bb9ed0d49e2831255d3be1aa3a56503d77a))


### Documentation

* fix typos ([#13](https://github.com/hyperspell/python-sdk/issues/13)) ([84bf7b5](https://github.com/hyperspell/python-sdk/commit/84bf7b55e593e35b5b68ebac64909f21d3431938))
* **raw responses:** fix duplicate `the` ([#18](https://github.com/hyperspell/python-sdk/issues/18)) ([f99b1ca](https://github.com/hyperspell/python-sdk/commit/f99b1cadaa53c54cb27082d401fe376e0ce2f618))
